==> bigloo3.1a.tar.gz: bigloo3.1a/api/ssl/src/Java/ssl_client_socket15.java <==
/*=====================================================================*/
/*    .../project/bigloo/api/ssl/src/Java/ssl_client_socket15.java     */
/*    -------------------------------------------------------------    */
/*    Author      :  Manuel Serrano                                    */
/*    Creation    :  Fri Jul  8 11:11:03 2005                          */
/*    Last change :  Fri Nov 16 15:43:28 2007 (serrano)                */
/*    Copyright   :  2005-07 Manuel Serrano                            */
/*    -------------------------------------------------------------    */
/*    JDK>=1.5 SSL Java socket                                         */
/*=====================================================================*/

package bigloo.ssl;

import bigloo.*;

import java.io.*;
import java.net.*;
import javax.net.ssl.*;
import java.security.*;

import org.apache.commons.ssl.*;

public class ssl_client_socket extends client_socket {
   
   public static final int BGLSSL_SSLV2 = 1;
   public static final int BGLSSL_SSLV3 = 2;
   public static final int BGLSSL_SSLV23 = 3;
   public static final int BGLSSL_TLSV1 = 4;
   public static final int BGLSSL_DTLSV1 = 5;

   public ssl_client_socket(final byte[] hostname,
			    final int port,
			    final boolean block,
			    final int ms,
			    final int proto,
			    final Object cert,
			    final Object pkey,
			    Object caList,
			    Object acceptedCerts) {
      super();
      
      try {
	 SSLClient client = new SSLClient();

	 client.setCheckHostname(false);

	 // first the trusted CAs
	 if (caList != nil.nil) {
	    while (caList != nil.nil) {
	       pair cell = (pair)caList;
	       certificate ca = (certificate)ssl.certificate_native(cell.car);
	       client.addTrustMaterial(new TrustMaterial(ca.x509));
	       caList = cell.cdr;
	    }
	    // if we have trusted CAs we want authentication
	    client.setNeedClientAuth(true);
	 }
	 // then the key material
	 if (cert != bbool.faux) {
	    certificate c = (certificate)ssl.certificate_native(cert);
	    private_key pk = (private_key)ssl.private_key_native(pkey);
	    client.setKeyMaterial(new KeyMaterial(c.fname, pk.fname, 
						  new char[0]));
	 }
	 // now make the socket
	 SSLSocket sslsocket =
	    (SSLSocket)client.createSocket( new String( hostname ), port );

	 // check the accepted certs if any
	 if (acceptedCerts != bbool.faux) {
	    Principal p = sslsocket.getSession().getPeerPrincipal();
	    boolean ok = false;
	    while(acceptedCerts != nil.nil){
	       pair cell = (pair)acceptedCerts;
	       certificate c = (certificate)ssl.certificate_native(cell.car);
	       if (p.equals(c.x509.getSubjectX500Principal())){
		  ok = true;
		  break;
	       }
	       acceptedCerts = cell.cdr;
	    }
	    if (!ok) {
	       socket_error("make-ssl-client-socket",
			    "Presented certificate is not in the accept list",
			    p.getName());
	    }
	 }
      
	 blocking = block;
	 socket = sslsocket;

	 set_socket_io_ports( socket, blocking );
      }
      catch (final Exception _) {
	 _.printStackTrace();
	 socket_error( "make-ssl-client-socket",
		       "cannot create socket",
		       unspecified.unspecified );
      }
   }

   public ssl_client_socket(final client_socket sock,
			    final int proto,
			    final Object cert,
			    final Object pkey,
			    Object caList,
			    Object acceptedCerts) {
      super();
      
      try {
	 SSLClient client = new SSLClient();
	 Socket socket = sock.socket;

	 client.setCheckHostname(false);

	 // first the trusted CAs
	 if (caList != nil.nil) {
	    while (caList != nil.nil) {
	       pair cell = (pair)caList;
	       certificate ca = (certificate)ssl.certificate_native(cell.car);
	       client.addTrustMaterial(new TrustMaterial(ca.x509));
	       caList = cell.cdr;
	    }
	    // if we have trusted CAs we want authentication
	    client.setNeedClientAuth(true);
	 }
	 // then the key material
	 if (cert != bbool.faux) {
	    certificate c = (certificate)ssl.certificate_native(cert);
	    private_key pk = (private_key)ssl.private_key_native(pkey);
	    client.setKeyMaterial(new KeyMaterial(c.fname, pk.fname, 
						  new char[0]));
	 }
	 // now make the socket
	 SSLSocket sslsocket =
	    (SSLSocket)client.createSocket(socket,
					   socket.getInetAddress().getHostName(),
					   socket.getPort(),
					   true);

	 // check the accepted certs if any
	 if (acceptedCerts != bbool.faux) {
	    Principal p = sslsocket.getSession().getPeerPrincipal();
	    boolean ok = false;
	    while(acceptedCerts != nil.nil){
	       pair cell = (pair)acceptedCerts;
	       certificate c = (certificate)ssl.certificate_native(cell.car);
	       if (p.equals(c.x509.getSubjectX500Principal())){
		  ok = true;
		  break;
	       }
	       acceptedCerts = cell.cdr;
	    }
	    if (!ok) {
	       socket_error("make-ssl-client-socket",
			    "Presented certificate is not in the accept list",
			    p.getName());
	    }
	 }
      
	 blocking = sock.blocking;
	 socket = sslsocket;

	 set_socket_io_ports( socket, blocking );
      }
      catch (final Exception _) {
	 _.printStackTrace();
	 socket_error( "make-ssl-client-socket",
		       "cannot create socket",
		       unspecified.unspecified );
      }
   }

   public ssl_client_socket(final Socket socket, final boolean blocking) {
      super(socket, blocking);
   }
}

==> bigloo3.2b.tar.gz: bigloo3.2b/api/ssl/src/Java/ssl_client_socket15.java <==
/*=====================================================================*/
/*    .../project/bigloo/api/ssl/src/Java/ssl_client_socket15.java     */
/*    -------------------------------------------------------------    */
/*    Author      :  Manuel Serrano                                    */
/*    Creation    :  Fri Jul  8 11:11:03 2005                          */
/*    Last change :  Sun Sep  7 16:23:22 2008 (serrano)                */
/*    Copyright   :  2005-08 Manuel Serrano                            */
/*    -------------------------------------------------------------    */
/*    JDK>=1.5 SSL Java socket                                         */
/*=====================================================================*/

package bigloo.ssl;

import bigloo.*;

import java.io.*;
import java.net.*;
import javax.net.ssl.*;
import java.security.*;

import org.apache.commons.ssl.*;

public class ssl_client_socket extends client_socket {
   
   public static final int BGLSSL_SSLV2 = 1;
   public static final int BGLSSL_SSLV3 = 2;
   public static final int BGLSSL_SSLV23 = 3;
   public static final int BGLSSL_TLSV1 = 4;
   public static final int BGLSSL_DTLSV1 = 5;

   public ssl_client_socket(final byte[] hostname,
			    final int port,
			    final int ms,
			    final int proto,
			    final Object cert,
			    final Object pkey,
			    Object caList,
			    Object acceptedCerts,
			    byte[] inbuf,
			    byte[] outbuf ) {
      super();
      
      try {
	 SSLClient client = new SSLClient();

	 client.setCheckHostname(false);

	 // first the trusted CAs
	 if (caList != nil.nil) {
	    while (caList != nil.nil) {
	       pair cell = (pair)caList;
	       certificate ca = (certificate)ssl.certificate_native(cell.car);
	       client.addTrustMaterial(new TrustMaterial(ca.x509));
	       caList = cell.cdr;
	    }
	    // if we have trusted CAs we want authentication
	    client.setNeedClientAuth(true);
	 }
	 // then the key material
	 if (cert != bbool.faux) {
	    certificate c = (certificate)ssl.certificate_native(cert);
	    private_key pk = (private_key)ssl.private_key_native(pkey);
	    client.setKeyMaterial(new KeyMaterial(c.fname, pk.fname, 
						  new char[0]));
	 }
	 // now make the socket
	 SSLSocket sslsocket =
	    (SSLSocket)client.createSocket( new String( hostname ), port );

	 // check the accepted certs if any
	 if (acceptedCerts != bbool.faux) {
	    Principal p = sslsocket.getSession().getPeerPrincipal();
	    boolean ok = false;
	    while(acceptedCerts != nil.nil){
	       pair cell = (pair)acceptedCerts;
	       certificate c = (certificate)ssl.certificate_native(cell.car);
	       if (p.equals(c.x509.getSubjectX500Principal())){
		  ok = true;
		  break;
	       }
	       acceptedCerts = cell.cdr;
	    }
	    if (!ok) {
	       socket_error("make-ssl-client-socket",
			    "Presented certificate is not in the accept list",
			    p.getName());
	    }
	 }
      
	 socket = sslsocket;

	 set_socket_io_ports( socket, inbuf, outbuf );
      }
      catch (final Exception _) {
	 _.printStackTrace();
	 socket_error( "make-ssl-client-socket",
		       "cannot create socket",
		       unspecified.unspecified );
      }
   }

   public ssl_client_socket(final client_socket sock,
			    final int proto,
			    final Object cert,
			    final Object pkey,
			    Object caList,
			    Object acceptedCerts) {
      super();
      
      try {
	 SSLClient client = new SSLClient();
	 Socket socket = sock.socket;

	 client.setCheckHostname(false);

	 // first the trusted CAs
	 if (caList != nil.nil) {
	    while (caList != nil.nil) {
	       pair cell = (pair)caList;
	       certificate ca = (certificate)ssl.certificate_native(cell.car);
	       client.addTrustMaterial(new TrustMaterial(ca.x509));
	       caList = cell.cdr;
	    }
	    // if we have trusted CAs we want authentication
	    client.setNeedClientAuth(true);
	 }
	 // then the key material
	 if (cert != bbool.faux) {
	    certificate c = (certificate)ssl.certificate_native(cert);
	    private_key pk = (private_key)ssl.private_key_native(pkey);
	    client.setKeyMaterial(new KeyMaterial(c.fname, pk.fname, 
						  new char[0]));
	 }
	 // now make the socket
	 SSLSocket sslsocket =
	    (SSLSocket)client.createSocket(socket,
					   socket.getInetAddress().getHostName(),
					   socket.getPort(),
					   true);

	 // check the accepted certs if any
	 if (acceptedCerts != bbool.faux) {
	    Principal p = sslsocket.getSession().getPeerPrincipal();
	    boolean ok = false;
	    while(acceptedCerts != nil.nil){
	       pair cell = (pair)acceptedCerts;
	       certificate c = (certificate)ssl.certificate_native(cell.car);
	       if (p.equals(c.x509.getSubjectX500Principal())){
		  ok = true;
		  break;
	       }
	       acceptedCerts = cell.cdr;
	    }
	    if (!ok) {
	       socket_error("make-ssl-client-socket",
			    "Presented certificate is not in the accept list",
			    p.getName());
	    }
	 }
      
	 socket = sslsocket;

	 set_socket_io_ports( socket, new byte[ 8192 ], new byte[ 8192 ] );
      }
      catch (final Exception _) {
	 _.printStackTrace();
	 socket_error( "make-ssl-client-socket",
		       "cannot create socket",
		       unspecified.unspecified );
      }
   }

   public ssl_client_socket(final Socket socket,
			    final byte[] inbuf,
			    final byte[] outbuf ) {
      super(socket, inbuf, outbuf);
   }
}
